from os_image_handler import image_handler as ih

##################################################################################
#
# this is a simple module for the creation of a feature graphic for Android
#
##################################################################################

# finals
OUTPUT_WIDTH = 1024
OUTPUT_HEIGHT = 500


def create_feature_graphic(logo_path,
                           output_path,
                           fixed_background_hex_color=None,
                           gradient_background_hex_color_start=None,
                           gradient_background_hex_color_end=None,
                           app_name=None,
                           app_name_font_color_hex='#ffffff',
                           app_name_custom_font_path=None,
                           app_name_max_font_size=32,
                           app_name_distance_from_top=390,
                           logo_max_width_pixels=300,
                           logo_distance_from_top=40):
    """Will create the feature graphic.

    Parameters:
    :param logo_path: the path to your logo file
    :param output_path: the path to which the feature graphic image will be saved
    :param fixed_background_hex_color: if you would like to use a fixed hex for the background, set it here
    :param gradient_background_hex_color_start: if you would like to use a dynamic background, set the start color here
    :param gradient_background_hex_color_end: if you would like to use a dynamic background, set the end color here
    :param app_name: the name of your app
    :param app_name_font_color_hex: the color of your app name
    :param app_name_custom_font_path: you can use a custom font for your app name. Just set it here
    :param app_name_max_font_size: if the size is too big/small for you, you can set here a new static size
    :param app_name_distance_from_top: set here the distance of the app name, from the image top
    :param logo_max_width_pixels: the maximum width of the image (the height will be scaled proportionally
    :param logo_distance_from_top: the distance of the logo from the top
    """

    # create a background canvas with a background gradient color
    background = ih.create_new_image(OUTPUT_WIDTH, OUTPUT_HEIGHT, fixed_background_hex_color, gradient_background_hex_color_start, gradient_background_hex_color_end)

    # calculate centers
    center_point_x = background.width / 2
    center_point_y = background.height / 2

    # add text
    if app_name is not None:
        font_size = app_name_max_font_size
        if len(app_name) > 38:
            font_size = 20
        ih.draw_text_on_img(background, app_name, center_point_x - (len(app_name) * font_size / 2) / 1.8, app_name_distance_from_top, app_name_font_color_hex, app_name_custom_font_path, font_size)

    # add the logo
    logo_img = ih.load_img(logo_path)
    logo_img = ih.resize_img_by_width(logo_img, logo_max_width_pixels)
    ih.paste_image(background, logo_img, center_point_x - logo_img.width / 2, logo_distance_from_top)

    # save
    ih.save_img(background, output_path)



import os_android_feature_graphic_maker.feature_graphic_maker as fgm

fgm.create_feature_graphic(logo_path='/Users/home/Desktop/icons/chubby_logo.png',
                           output_path='/Users/home/Desktop/icons/feature_graphic.png',
                           gradient_background_hex_color_start='#ed4264',
                           gradient_background_hex_color_end='#ffedbc',
                           app_name='Catch The Chubby Hedgehog!',
                           app_name_custom_font_path='/Users/home/Library/Fonts/Consolas.ttf')


from distutils.core import setup

setup(
    name='os_android_feature_graphic_maker',
    packages=['os_android_feature_graphic_maker', 'os_android_feature_graphic_maker.modules'],
    version='1.00',  # Start with a small number and increase it with every change you make
    license='MIT',  # Chose a license from here: https://help.github.com/articles/licensing-a-repository
    description='This script will create a simple feature graphic for you to use in the Google Play store',  # Give a short description about your library
    author='Oz Shabat',  # Type in your name
    author_email='osapps@gmail.com',  # Type in your E-Mail
    url='https://github.com/osfunapps/os_android_feature_graphic_maker-py',  # Provide either the link to your github or to your website
    keywords=['feature_graphic', 'android', 'google_play', 'tools', 'utils', 'automation'],  # Keywords that define your package best
    install_requires=['os_image_handler'],
    classifiers=[
        'Development Status :: 5 - Production/Stable',  # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package

        'Intended Audience :: Developers',  # Define that your audience are developers
        'Topic :: Software Development :: Build Tools',

        'License :: OSI Approved :: MIT License',  # Again, pick a license

        'Programming Language :: Python :: 3',  # Specify which pyhton versions that you want to support
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
)

